#!/usr/bin/perl -w

#--------------------------------------------------------------------
# FICHERO:  sencillo.pl
# OBJETIVO: Un programa sencillo, para ejemplos
# AUTOR:    Pedro Reina
# FECHA:    L.16.4.2001
#--------------------------------------------------------------------

#--------------------------------------------------------------------
# Declaracin de mdulos
#--------------------------------------------------------------------

use strict;              # Comprobaciones estrictas
use Gtk;                 # Interfaz grfico GTK

#--------------------------------------------------------------------
# Declaracin de variables Perl
#--------------------------------------------------------------------

my $Respuesta;           # La respuesta final a la orden

#--------------------------------------------------------------------
# Declaracin de variables GTK
#--------------------------------------------------------------------

my $Ventana;             # Ventana de la aplicacin
my $BarraMenu;           # Barra del men principal
my @ItemsMenu;           # El array del men principal
my $Estado;              # Barra de estado
my $Contexto;            # Contexto para la barra de estado
my $Caja;                # Un contenedor para los controles
my $CajaRespuesta;       # Un contenedor para poner la respuesta
my $AreaRespuesta;       # La zona de texto en que mostraremos el resultado
my $Desplazamiento;      # La barra de desplazamiento

my $IndRespuesta;        # Indicacin para la zona de respuesta
my $IndEstado;           # Indicacin para la barra de estado

#--------------------------------------------------------------------
# Programa principal
#--------------------------------------------------------------------

# Arrancamos el motor GTK;
init Gtk;

# Creamos la ventana principal
$Ventana = new Gtk::Window ("toplevel");

# Le ponemos un ttulo
$Ventana->set_title ("sencillo");

# Le ponemos un poquito de borde
$Ventana->border_width (2);

# Definimos el tamao que nos gusta
$Ventana->set_usize (400, 300);

# Creamos la caja para poner los controles
$Caja = new Gtk::VBox (0, 0);

# Definicin del men principal completo
@ItemsMenu =
  (
    { path        => '/_Archivo',
      type        => '<Branch>'
    },

    { path        => '/Archivo/_Nuevo',
      accelerator => '<control>N',
      callback    => \&Escribe
    },

    { path        => '/Archivo/_Abrir',
      accelerator => '<control>A',
      callback    => \&Escribe
    },

    { path        => '/Archivo/sep1',
      type        => '<Separator>'
    },

    { path        => '/Archivo/_Salir',
      accelerator => '<alt>X',
      callback    => \&CerrarAplicacion
    },

    { path        => '/_Editar',
      type        => '<Branch>'
    },

    { path        => '/_Editar/_Escribir',
      accelerator => '<control>E',
      callback    => \&Escribe
    },

    { path        => '/_Editar/_Limpiar',
      accelerator => '<control>L',
      callback    => \&Limpia
    },

    { path        => '/Eje_mplo',
      type        => '<Branch>'
    },

    { path        => '/Eje_mplo/Guardar _todo',
    },

    { path        => '/Eje_mplo/_Copiar',
      accelerator => '<control>C',
    },

    { path        => '/Eje_mplo/_Regla',
      type        => '<CheckItem>'
    },

    { path        => '/Eje_mplo/sep1',
      type        => '<Separator>'
    },

    { path        => '/Eje_mplo/_Normal',
      type        => '<RadioItem>'
    },

    { path        => '/Eje_mplo/_Imprimir...',
      accelerator => '<control>P',
    },

    { path        => '/_Controles',
      type        => '<Branch>'
    },

    { path        => '/_Controles/_Botones',
      accelerator => '<control>B',
      callback    => \&Botones
    },

    { path        => '/_Controles/Ca_sillas',
      accelerator => '<control>S',
      callback    => \&Casillas
    },

    { path        => '/_Opciones',
      type        => '<Branch>'
    },

    { path        => '/Ay_uda',
      type        => '<LastBranch>'
    },
  );

# Creamos la barra del men principal
$BarraMenu = PreparaMenuPrincipal ($Ventana);
$Caja->pack_start ($BarraMenu, 0, 1, 0);
$BarraMenu->show();

# Creamos la caja para poner la respuesta
$CajaRespuesta = new Gtk::HBox (0, 0);

# Definimos el rea de texto para mostrar la respuesta
$AreaRespuesta = new Gtk::Text (undef, undef);

# No permitimos editar su texto
$AreaRespuesta->set_editable (0);

# La aadimos a la caja de respuesta
$CajaRespuesta->pack_start ($AreaRespuesta, 1, 1, 0);

# La mostramos
$AreaRespuesta->show();

# Definimos la barra de desplazamiento
$Desplazamiento = new Gtk::VScrollbar ($AreaRespuesta->vadj);

# La aadimos a la caja de respuesta
$CajaRespuesta->pack_start ($Desplazamiento, 0, 0, 0);

# La mostramos
$Desplazamiento->show();

# Aadimos la caja de respuesta a la caja
$Caja->pack_start ($CajaRespuesta, 1, 1, 2);

# Mostramos la caja de respuesta
$CajaRespuesta->show();

# Definimos la barra de estado
$Estado = new Gtk::Statusbar();

# Aadimos la barra a la caja
$Caja->pack_start ($Estado, 0, 0, 2);

# Mostramos la barra
$Estado->show();

# Pedimos un contexto para la barra de estado
$Contexto = $Estado->get_context_id ("General");

# Ponemos un mensaje
$Estado->push ($Contexto, "Preparado");

# Registramos las llamadas para cerrar la aplicacin
$Ventana->signal_connect ("delete_event", \&CerrarAplicacion);

# Aadimos la caja a la ventana
$Ventana->add ($Caja);

# Mostramos la caja
$Caja->show();

# Definimos los "tooltips"
$IndRespuesta = new Gtk::Tooltips();
$IndEstado = new Gtk::Tooltips();  # Parece que no funciona

# Y los asignamos
$IndRespuesta->set_tip ($AreaRespuesta, "Aqu aparecen los resultados", "");
$IndEstado->set_tip ($Estado, "Muestra el estado de la aplicacin", "");

# Mostramos la ventana
$Ventana->show();

# El resto es cosa de GTK
main Gtk;

# As que hasta aqu no se debera llegar nunca
exit (0);

#--------------------------------------------------------------------
# Funciones
#--------------------------------------------------------------------

#--------------------------------------------------------------------
# FUNCION:  CerrarAplicacion()
# OBJETIVO: Cerrar el programa
#--------------------------------------------------------------------
sub CerrarAplicacion
  {
  Gtk->exit (0);
  return (0);
  }

#--------------------------------------------------------------------
# FUNCION:  PreparaMenuPrincipal()
#--------------------------------------------------------------------
sub PreparaMenuPrincipal
  {
  # Variables locales
  my ($Ventana) = @_;    # La ventana que nos pasan
  my $BarraMenu;         # La barra con el men principal
  my $Fabrica;           # El conjunto de mens
  my $Atajos;            # Los atajos de teclado

  # Creamos el conjunto de Atajos de teclado
  $Atajos = new Gtk::AccelGroup();

  # Creamos el conjunto de mens
  $Fabrica = new Gtk::ItemFactory ('Gtk::MenuBar', '<main>', $Atajos );
  $Fabrica->create_items (@ItemsMenu);

  # Asignamos los atajos a la ventana
  $Ventana->add_accel_group ($Atajos);

  # Devolvemos el men creado
  return ($Fabrica->get_widget ('<main>') );
  }

#--------------------------------------------------------------------
# FUNCION:  Escribe()
#--------------------------------------------------------------------
sub Escribe
  {
  $AreaRespuesta->insert (undef, undef, undef, "Hola, mundo\n");
  }

#--------------------------------------------------------------------
# FUNCION:  Limpia()
#--------------------------------------------------------------------
sub Limpia
  {
  $AreaRespuesta->delete_text (0, -1);
  }

#--------------------------------------------------------------------
# FUNCION:  Botones()
# OBJETIVO: Mostrar un ejemplo de botones de opcin
#--------------------------------------------------------------------
sub Botones
  {
  # Variables locales;
  my $Ventana;
  my $Cuadro;
  my $Caja;
  my $Boton1;
  my $Boton2;
  my $Boton3;

  # Creamos la ventana principal
  $Ventana = new Gtk::Window ("toplevel");

  # Le ponemos un ttulo
  $Ventana->set_title ("Botones de opcion");

  # Le ponemos un poquito de borde
  $Ventana->border_width (2);

  # Definimos el tamao que nos gusta
  $Ventana->set_usize (100, 100);

  # Creamos un cuadro
  $Cuadro = new Gtk::Frame("Eleccin");

  # Lo aadimos a la ventana
  $Ventana->add ($Cuadro);

  # Y lo mostramos
  $Cuadro->show();

  # Creamos una caja para poner los botones
  $Caja = new Gtk::VBox (0, 0);

  # Aadimos la caja al cuadro
  $Cuadro->add ($Caja);

  # Y la mostramos
  $Caja->show();

  # Creamos botones de opcin
  $Boton1 = new Gtk::RadioButton ("Todo");
  $Caja->add ($Boton1);

  $Boton2 = new Gtk::RadioButton ("Parte", $Boton1 );
  $Caja->add ($Boton2 );

  $Boton3 = new Gtk::RadioButton ("Nada", $Boton1);
  $Caja->add ($Boton3);

  # Y los mostramos
  $Boton1->show();
  $Boton2->show();
  $Boton3->show();

  # Registramos las llamadas para cerrar la aplicacin
  $Ventana->signal_connect ("delete_event", sub {$Ventana->destroy();});

  # Mostramos la ventana
  $Ventana->show();
  }

#--------------------------------------------------------------------
# FUNCION:  Casillas()
# OBJETIVO: Mostrar un ejemplo de casillas de verificacin
#--------------------------------------------------------------------
sub Casillas
  {
  # Variables locales;
  my $Ventana;
  my $Cuadro;
  my $Tabla;
  my $Casilla1;
  my $Casilla2;
  my $Casilla3;
  my $Casilla4;
  my $Casilla5;
  my $Casilla6;

  # Creamos la ventana principal
  $Ventana = new Gtk::Window ("toplevel");

  # Le ponemos un ttulo
  $Ventana->set_title ("Casillas");

  # Le ponemos un poquito de borde
  $Ventana->border_width (2);

  # Definimos el tamao que nos gusta
  $Ventana->set_usize (100, 100);

  # Creamos un cuadro
  $Cuadro = new Gtk::Frame("Comida");

  # Lo aadimos a la ventana
  $Ventana->add ($Cuadro );

  # Y lo mostramos
  $Cuadro->show();

  # Creamos una tabla para poner las casillas
  $Tabla = new Gtk::Table (3, 2, 0);

  # Aadimos la caja al cuadro
  $Cuadro->add ($Tabla);

  # Y la mostramos
  $Tabla->show();

  # Creamos las casillas
  $Casilla1 = new Gtk::CheckButton ("Carne");
  $Casilla2 = new Gtk::CheckButton ("Pescado");
  $Casilla3 = new Gtk::CheckButton ("Fruta");
  $Casilla4 = new Gtk::CheckButton ("Legumbre");
  $Casilla5 = new Gtk::CheckButton ("Helado");
  $Casilla6 = new Gtk::CheckButton ("Huevos");

  # Las aadimos a la tabla
  $Tabla->attach_defaults ($Casilla1, 0, 1, 0, 1);
  $Tabla->attach_defaults ($Casilla2, 1, 2, 0, 1);
  $Tabla->attach_defaults ($Casilla3, 2, 3, 0, 1);
  $Tabla->attach_defaults ($Casilla4, 0, 1, 1, 2);
  $Tabla->attach_defaults ($Casilla5, 1, 2, 1, 2);
  $Tabla->attach_defaults ($Casilla6, 2, 3, 1, 2);

  # Y las mostramos
  $Casilla1->show();
  $Casilla2->show();
  $Casilla3->show();
  $Casilla4->show();
  $Casilla5->show();
  $Casilla6->show();

  # Registramos las llamadas para cerrar la aplicacin
  $Ventana->signal_connect ("delete_event", sub {$Ventana->destroy();});

  # Mostramos la ventana
  $Ventana->show();
  }

